@@ -1,24 +1,24 @@
 package Pcore::App::API::Local::pgsql;
 
 use Pcore -class, -result, -sql;
-use Pcore::Util::UUID qw[uuid_v1mc_str];
+use Pcore::Util::UUID qw[uuid_v4_str];
 
 with qw[Pcore::App::API::Local];
 
 sub _db_add_schema_patch ( $self, $dbh ) {
     $dbh->add_schema_patch(
         1 => <<"SQL"
-            CREATE EXTENSION IF NOT EXISTS "uuid-ossp";
+            CREATE EXTENSION IF NOT EXISTS "pgcrypto";
 
             -- ROLE
             CREATE TABLE IF NOT EXISTS "api_role" (
-                "id" UUID PRIMARY KEY NOT NULL DEFAULT uuid_generate_v4(),
+                "id" UUID PRIMARY KEY NOT NULL DEFAULT gen_random_uuid(),
                 "name" TEXT NOT NULL UNIQUE
             );
 
             -- USER
             CREATE TABLE IF NOT EXISTS "api_user" (
-                "id" UUID PRIMARY KEY NOT NULL DEFAULT uuid_generate_v4(),
+                "id" UUID PRIMARY KEY NOT NULL DEFAULT gen_random_uuid(),
                 "name" TEXT NOT NULL UNIQUE,
                 "hash" BYTEA NOT NULL,
                 "enabled" BOOLEAN NOT NULL DEFAULT FALSE,
@@ -27,7 +27,7 @@ sub _db_add_schema_patch ( $self, $dbh ) {
 
             -- USER PERMISSION
             CREATE TABLE IF NOT EXISTS "api_user_permission" (
-                "id" UUID PRIMARY KEY NOT NULL DEFAULT uuid_generate_v4(),
+                "id" UUID PRIMARY KEY NOT NULL DEFAULT gen_random_uuid(),
                 "user_id" UUID NOT NULL REFERENCES "api_user" ("id") ON DELETE CASCADE, -- remove role assoc., on user delete
                 "role_id" UUID NOT NULL REFERENCES "api_role" ("id") ON DELETE RESTRICT -- prevent deleting role, if has assigned users
             );
@@ -36,7 +36,8 @@ sub _db_add_schema_patch ( $self, $dbh ) {
 
             -- USER TOKEN
             CREATE TABLE IF NOT EXISTS "api_user_token" (
-                "id" UUID PRIMARY KEY NOT NULL DEFAULT uuid_generate_v4(),
+                "id" UUID PRIMARY KEY NOT NULL DEFAULT gen_random_uuid(),
+                "type" INT2 NOT NULL,
                 "user_id" UUID NOT NULL REFERENCES "api_user" ("id") ON DELETE CASCADE,
                 "hash" BYTEA NOT NULL,
                 "desc" TEXT,
@@ -45,22 +46,12 @@ sub _db_add_schema_patch ( $self, $dbh ) {
 
             -- USER TOKEN PERMISSION
             CREATE TABLE IF NOT EXISTS "api_user_token_permission" (
+                "id" UUID PRIMARY KEY NOT NULL DEFAULT gen_random_uuid(),
                 "user_token_id" UUID NOT NULL REFERENCES "api_user_token" ("id") ON DELETE CASCADE,
                 "user_permission_id" UUID NOT NULL REFERENCES "api_user_permission" ("id") ON DELETE CASCADE
             );
 
             CREATE UNIQUE INDEX IF NOT EXISTS "idx_uniq_api_user_token_permission" ON "api_user_token_permission" ("user_token_id", "user_permission_id");
-
-            --- USER SESSION
-            CREATE TABLE IF NOT EXISTS "api_user_session" (
-                "id" UUID PRIMARY KEY NOT NULL DEFAULT uuid_generate_v4(),
-                "user_id" UUID NOT NULL REFERENCES "api_user" ("id") ON DELETE CASCADE,
-                "hash" BYTEA NOT NULL,
-                "created" INT8 NOT NULL DEFAULT EXTRACT(EPOCH FROM NOW()),
-                "updated" INT8 NOT NULL DEFAULT EXTRACT(EPOCH FROM NOW()),
-                "ip" BYTEA NOT NULL,
-                "agent" TEXT NOT NULL
-            );
 SQL
     );
 
@@ -69,7 +60,7 @@ SQL
 
 sub _db_add_roles ( $self, $dbh, $roles, $cb ) {
     $dbh->do(
-        [ q[INSERT INTO "api_role"], VALUES [ map { { id => uuid_v1mc_str, name => $_ } } $roles->@* ], 'ON CONFLICT DO NOTHING' ],
+        [ q[INSERT INTO "api_role"], VALUES [ map { { name => $_ } } $roles->@* ], 'ON CONFLICT DO NOTHING' ],
         sub ( $dbh, $res, $data ) {
             $cb->($res);
 
@@ -81,11 +72,11 @@ sub _db_add_roles ( $self, $dbh, $roles, $cb ) {
 }
 
 sub _db_create_user ( $self, $dbh, $user_name, $hash, $enabled, $cb ) {
-    my $user_id = uuid_v1mc_str;
+    my $user_id = uuid_v4_str;
 
     $dbh->do(
         'INSERT INTO "api_user" ("id", "name", "hash", "enabled") VALUES (?, ?, ?, ?) ON CONFLICT DO NOTHING',
-        [ SQL_UUID $user_name, SQL_BYTEA $hash, SQL_BOOL $enabled ],
+        [ SQL_UUID $user_id, SQL_UUID $user_name, SQL_BYTEA $hash, SQL_BOOL $enabled ],
         sub ( $dbh, $res, $data ) {
             if ( !$res->{rows} ) {
                 $cb->( result 500 );
@@ -105,7 +96,7 @@ sub _db_set_user_permissions ( $self, $dbh, $user_id, $roles_ids, $cb ) {
     my $modified;
 
     $dbh->do(
-        [ 'INSERT INTO "api_user_permission"', VALUES [ map { { role_id => $_, user_id => SQL_UUID $user_id } } $roles_ids->@* ], 'ON CONFLICT DO NOTHING' ],
+        [ 'INSERT INTO "api_user_permission"', VALUES [ map { { role_id => SQL_UUID $_, user_id => SQL_UUID $user_id } } $roles_ids->@* ], 'ON CONFLICT DO NOTHING' ],
         sub ( $dbh, $res, $data ) {
             if ( !$res ) {
                 $cb->( result 500 );
@@ -153,11 +144,11 @@ sub _db_set_user_permissions ( $self, $dbh, $user_id, $roles_ids, $cb ) {
 ## |======+======================+================================================================================================================|
 ## |    3 |                      | Subroutines::ProhibitUnusedPrivateSubroutines                                                                  |
 ## |      | 8                    | * Private subroutine/method '_db_add_schema_patch' declared but not used                                       |
-## |      | 70                   | * Private subroutine/method '_db_add_roles' declared but not used                                              |
-## |      | 83                   | * Private subroutine/method '_db_create_user' declared but not used                                            |
-## |      | 104                  | * Private subroutine/method '_db_set_user_permissions' declared but not used                                   |
+## |      | 61                   | * Private subroutine/method '_db_add_roles' declared but not used                                              |
+## |      | 74                   | * Private subroutine/method '_db_create_user' declared but not used                                            |
+## |      | 95                   | * Private subroutine/method '_db_set_user_permissions' declared but not used                                   |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 83, 104              | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
+## |    3 | 74, 95               | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
