@@ -1,7 +1,7 @@
 package Pcore::WebSocket::Protocol::pcore::Request;
 
 use Pcore -class, -result;
-use Pcore::Util::Scalar qw[blessed];
+use Pcore::Util::Scalar qw[is_blessed_ref];
 
 use overload    #
   q[&{}] => sub ( $self, @ ) {
@@ -29,10 +29,6 @@ sub IS_CALLBACK ($self) {
     return 1;
 }
 
-sub wantarray ($self) {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
-    return !!$self->{_cb};
-}
-
 sub _respond ( $self, @ ) {
     die q[Already responded] if $self->{_responded};
 
@@ -42,7 +38,7 @@ sub _respond ( $self, @ ) {
     if ( my $cb = delete $self->{_cb} ) {
 
         # return response, if callback is defined
-        $cb->( blessed $_[1] ? $_[1] : result splice @_, 1 );
+        $cb->( is_blessed_ref $_[1] ? $_[1] : result splice @_, 1 );
     }
 
     return;
